%if 0%{?rhel} < 7
%{!?__global_ldflags: %global __global_ldflags -Wl,-z,relro}
%endif

%global module Ipopt

# Define a macro for calling ../configure instead of ./configure
%global dconfigure %(printf %%s '%configure' | sed 's!\./configure!../configure!g')

## Define libraries' destination
%global _incmpidir %{_includedir}/openmpi-%{_arch}
%global _libmpidir %{_libdir}/openmpi/lib
%global _binmpidir %{_libdir}/openmpi/bin
%global _incmpichdir %{_includedir}/mpich-%{_arch}
%global _libmpichdir %{_libdir}/mpich/lib
%global _binmpichdir %{_libdir}/mpich/bin

%if 0%{?rhel} || 0%{?rhel} < 7
%ifarch %{power64}
%global with_mpich 0
%endif
%endif
%if 0%{?rhel} || 0%{?rhel} < 7
%ifnarch %{power64}
%global with_mpich 1
%endif
%endif
%if 0%{?fedora} || 0%{?rhel} >= 7
%global with_openmpi 1
%global with_mpich 1
%endif

%ifarch s390x
%if 0%{?fedora} < 26
%global with_openmpi 0
%global with_mpich 0
%else
%global with_openmpi 1
%global with_mpich 1
%endif
%endif

%global with_asl 1

Name:  coin-or-%{module}
Group: Applications/Engineering
Summary: Interior Point OPTimizer
Version: 3.12.8
Release: 5%{?dist}
License: EPL and GPLv2+
URL:  https://projects.coin-or.org/%{module}
Source0: http://www.coin-or.org/download/pkgsource/%{module}/%{module}-%{version}.tgz
BuildRequires: atlas-devel
BuildRequires: blas-devel
BuildRequires: gcc-gfortran
BuildRequires: doxygen
BuildRequires: glpk-devel
BuildRequires: graphviz
BuildRequires: lapack-devel
BuildRequires: MUMPS-devel
BuildRequires: metis-devel
%if 0%{?with_asl}
BuildRequires: mp-devel
%endif
BuildRequires: openssh-clients
BuildRequires: pkgconfig
BuildRequires: readline-devel

Requires:  %{name}-common = %{version}-%{release}

# Build with parallel mumps solver
Patch0: %{name}-mumps.patch

# Correct underlink of libdl
Patch1: %{name}-underlink.patch

%description
Ipopt (Interior Point OPTimizer, pronounced eye-pea-Opt) is a software
package for large-scale nonlinear optimization. It is designed to find
(local) solutions of mathematical optimization problems of the from

   min     f(x)
x in R^n

s.t.       g_L <= g(x) <= g_U
           x_L <=  x   <= x_U

where f(x): R^n --> R is the objective function, and g(x): R^n --> R^m are
the constraint functions. The vectors g_L and g_U denote the lower and upper
bounds on the constraints, and the vectors x_L and x_U are the bounds on
the variables x. The functions f(x) and g(x) can be non-linear and non-convex,
but should be twice continuously differentiable. Note that equality
constraints can be formulated in the above formulation by setting the
corresponding components of g_L and g_U to the same value.

%package	devel
Summary:	Development files for %{name}
Group:		Development/Libraries
Requires:	coin-or-CoinUtils-devel
Requires:	MUMPS-devel >= 4.10.0-21
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package	common
Summary:	Documentation files for %{name}
BuildArch:	noarch
Provides:       %{name}-common = 0:%{version}-%{release}
Obsoletes:      %{name}-doc <= 0:3.11.9-3  

%description	common
This package contains the HTML documentation,
a PDF tutorial to use %{name} and related
license files.

########################################################
%if 0%{?with_openmpi}
%package openmpi
Summary: %{name} compiled against openmpi
BuildRequires:	MUMPS-openmpi-devel >= 4.10.0-21
BuildRequires:	blacs-openmpi-devel
BuildRequires:	openmpi-devel
BuildRequires:	scalapack-openmpi-devel
BuildRequires:	ptscotch-openmpi-devel

Requires: %{name}-common = %{version}-%{release}
Requires: openmpi
%description openmpi
%{name} libraries compiled against openmpi.

%package openmpi-devel
Summary: The %{name} headers and development-related files
Requires: %{name}-openmpi%{?_isa} = %{version}-%{release}
%description openmpi-devel
Shared links, header files for %{name}.
%endif
##########################################################
########################################################
%if 0%{?with_mpich}
%package mpich
Summary: %{name} compiled against openmpi
BuildRequires:	MUMPS-mpich-devel >= 4.10.0-21
BuildRequires:	blacs-mpich-devel
BuildRequires:	mpich-devel
BuildRequires:	scalapack-mpich-devel
BuildRequires:	ptscotch-mpich-devel

Requires: %{name}-common = %{version}-%{release}
Requires: mpich
%description mpich
%{name} libraries compiled against MPICH.

%package mpich-devel
Summary: The %{name} headers and development-related files
Requires: %{name}-mpich%{?_isa} = %{version}-%{release}
%description mpich-devel
Shared links, header files for %{name}.
%endif
##########################################################

%prep
%setup -q -n %{module}-%{version}
%patch1 -p1

sed -i -e 's! -shared ! -Wl,--as-needed\0!g' configure

# Update the various config.guess to upstream release for aarch64 support
for cdir in `find ./ -name config.guess`
do
       cp /usr/lib/rpm/config.{guess,sub} `dirname $cdir`
done

%build

#######################################################
## Build serial version

mkdir -p %{name}-%{version}-serial
cd %{name}-%{version}-serial
CFLAGS="%{optflags}"
OPT_CFLAGS="%{__global_ldflags} -Wl,-z,now"
CDEFS="-DIPOPT_BUILD -DHAVE_MPI_INITIALIZED=0" 
CPPFLAGS="-I%{_includedir}/MUMPS"
LDFLAGS="%{__global_ldflags} -Wl,-z,now"
CXXFLAGS="%{optflags} -Wl,-z,now"
OPT_CXXFLAGS="%{__global_ldflags} -Wl,-z,now"
CXXDEFS="-DIPOPT_BUILD -DHAVE_MPI_INITIALIZED=0" 
CPPFLAGS="-I%{_includedir}/MUMPS"
CXXLIBS="-L%{_libdir} -ldmumps -lblas -llapack -lmetis"
%dconfigure CC=gcc CXX=g++ F77=gfortran CFLAGS="$CFLAGS" CXXFLAGS="$CXXFLAGS" \
            LDFLAGS="$LDFLAGS" CXXLIBS="$CXXLIBS" \
 --with-metis-incdir=%{_includedir} --with-metis-lib="-L%{_libdir} -lmetis" \
 --with-mumps-incdir=%{_includedir}/MUMPS --with-mumps-lib="-L%{_libdir} -ldmumps" \
 --with-blas-incdir=%{_includedir}/lapacke --with-blas-lib="-L%{_libdir} -lblas" \
 --with-lapack-incdir=%{_includedir}/lapacke --with-lapack-lib="-L%{_libdir} -llapack" \
%if 0%{?with_asl}
%if 0%{?rhel} && 0%{?rhel} < 7
 --with-asl-lib="-L%{_libdir}/mp -Wl,-rpath -Wl,%{_libdir}/mp -lasl -lmp" --with-asl-incdir="%{_includedir}/asl" \
%else
 --with-asl-lib="-lasl -lmp" --with-asl-incdir="%{_includedir}/asl" \
%endif
%endif
 --enable-shared

echo 'LATEX_BATCHMODE = YES' >> doxydoc/doxygen.conf

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%if 0%{?rhel} && 0%{?rhel} < 7
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{_libdir}:%{_libdir}/mp
%else
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{_libdir}
%endif
make %{?_smp_mflags} all doxydoc
cd ..

#######################################################

#######################################################
## Build MPI version
%if 0%{?with_openmpi}
patch -p1 < %{PATCH0}

%if 0%{?fedora}
%global mpifort_cflags %(env PKG_CONFIG_PATH=%{_libmpidir}/pkgconfig pkg-config --cflags ompi-fort)
%global mpifort_libs %(env PKG_CONFIG_PATH=%{_libmpidir}/pkgconfig pkg-config --libs ompi-fort)
%global mpi_libs %(env PKG_CONFIG_PATH=%{_libmpidir}/pkgconfig pkg-config --libs ompi)
%endif
%if 0%{?rhel}
%global mpifort_cflags -pthread -I%{_libmpidir} -I%{_incmpidir}
%global mpifort_libs -L%{_libmpidir} -Wl,-rpath -Wl,%{_libmpidir} -lmpi_mpifh
%global mpi_libs -L%{_libmpidir} -Wl,-rpath -Wl,%{_libmpidir} -lmpi
%endif

mkdir -p %{name}-%{version}-openmpi
cd %{name}-%{version}-openmpi
%{_openmpi_load}
CFLAGS="%{optflags} -Wl,-z,now"
OPT_CFLAGS="-Wl,-z,relro -Wl,-z,now"
CDEFS="-DHAVE_MPI_INITIALIZED=1 -DIPOPT_BUILD"
CPPFLAGS="%{mpifort_cflags}"
LDFLAGS="%{__global_ldflags} -Wl,-z,now"
CXXFLAGS="%{optflags} -Wl,-z,now"
OPT_CXXFLAGS="-Wl,-z,relro -Wl,-z,now"
CXXDEFS="-DHAVE_MPI_INITIALIZED=1 -DIPOPT_BUILD"
CPPFLAGS="%{mpifort_cflags}"
CXXLIBS="%{mpi_libs} %{mpifort_libs} -lmpiblacs -lscalapack -ldmumps -lmumps_common -lptscotcherr -lptscotch -lptesmumps"
export CC=%{_libdir}/openmpi/bin/mpicc
export CXX=%{_libdir}/openmpi/bin/mpic++
export F77=%{_libdir}/openmpi/bin/mpif77
%dconfigure --with-mumps-incdir=%{_includedir}/openmpi-%{_arch} --with-mumps-lib="-L%{_libdir}/openmpi/lib -ldmumps -lmumps_common" \
%if 0%{?with_asl}
%if 0%{?rhel} && 0%{?rhel} < 7
 --with-asl-lib="-L%{_libdir}/mp -Wl,-rpath -Wl,%{_libdir}/mp -lasl -lmp" --with-asl-incdir="%{_includedir}/asl" \
%else
 --with-asl-lib="-lasl -lmp" --with-asl-incdir="%{_includedir}/asl" \
%endif
%endif
            MPICC=%{_libdir}/openmpi/bin/mpicc \
            MPICXX=%{_libdir}/openmpi/bin/mpic++ \
            MPIF77=%{_libdir}/openmpi/bin/mpif77 \
            ADD_CFLAGS="-fopenmp" \
            ADD_FFLAGS="-fopenmp" \
            ADD_CXXFLAGS="-fopenmp" \ 
            CFLAGS="$CFLAGS" CXXFLAGS="$CXXFLAGS" \
            LDFLAGS="$LDFLAGS" CXXLIBS="$CXXLIBS" 
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%if 0%{?rhel} && 0%{?rhel} < 7
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{_libdir}/openmpi/lib:%{_libdir}/mp
%else
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{_libdir}/openmpi/lib
%endif
make %{?_smp_mflags} all
%{_openmpi_unload}
cd ..
%endif

#######################################################
## Build MPICH version
%if 0%{?with_mpich}

%global mpich_cflags %(env PKG_CONFIG_PATH=%{_libmpichdir}/pkgconfig pkg-config --cflags mpich)
%global mpich_libs %(env PKG_CONFIG_PATH=%{_libmpichdir}/pkgconfig pkg-config --libs mpich)

mkdir -p %{name}-%{version}-mpich
cd %{name}-%{version}-mpich
%{_mpich_load}
CFLAGS="%{optflags} -Wl,-z,now"
OPT_CFLAGS="-Wl,-z,relro -Wl,-z,now"
CDEFS="-DHAVE_MPI_INITIALIZED=1 -DIPOPT_BUILD"
CPPFLAGS="%{mpich_cflags}"
LDFLAGS="%{__global_ldflags} -Wl,-z,now"
CXXFLAGS="%{optflags} -Wl,-z,now"
OPT_CXXFLAGS="-Wl,-z,relro -Wl,-z,now"
CXXDEFS="-DHAVE_MPI_INITIALIZED=1 -DIPOPT_BUILD"
CPPFLAGS="%{mpich_cflags}"
CXXLIBS="%{mpich_libs} -lmpiblacs -lscalapack -ldmumps -lmumps_common -lptscotcherr -lptscotch -lptesmumps"
export CC=%{_libdir}/mpich/bin/mpicc
export CXX=%{_libdir}/mpich/bin/mpic++
export F77=%{_libdir}/mpich/bin/mpifort
%dconfigure --with-mumps-incdir=%{_includedir}/mpich-%{_arch} --with-mumps-lib="-L%{_libdir}/mpich/lib -ldmumps -lmumps_common -lmpich" \
%if 0%{?with_asl}
%if 0%{?rhel} && 0%{?rhel} < 7
 --with-asl-lib="-L%{_libdir}/mp -Wl,-rpath -Wl,%{_libdir}/mp -lasl -lmp" --with-asl-incdir="%{_includedir}/asl" \
%else
 --with-asl-lib="-lasl -lmp" --with-asl-incdir="%{_includedir}/asl" \
%endif
%endif
            MPICC=%{_libdir}/mpich/bin/mpicc \
            MPICXX=%{_libdir}/mpich/bin/mpic++ \
            MPIF77=%{_libdir}/mpich/bin/mpif77 \
            ADD_CFLAGS="-fopenmp" \
            ADD_FFLAGS="-fopenmp" \
            ADD_CXXFLAGS="-fopenmp" \ 
            CFLAGS="$CFLAGS" CXXFLAGS="$CXXFLAGS" \
            LDFLAGS="$LDFLAGS" CXXLIBS="$CXXLIBS" 
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%if 0%{?rhel} && 0%{?rhel} < 7
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{_libdir}/mpich/lib:%{_libdir}/mp
%else
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{_libdir}/mpich/lib
%endif
make %{?_smp_mflags} all
%{_mpich_unload}
cd ..
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%install

#######################################################
## Install MPI version
%if 0%{?with_openmpi}

mkdir -p $RPM_BUILD_ROOT%{_libmpidir}
mkdir -p $RPM_BUILD_ROOT%{_binmpidir}
mkdir -p $RPM_BUILD_ROOT%{_incmpidir}
mkdir -p %{name}-%{version}-openmpi/headers

cp -a %{name}-%{version}-openmpi/src/Interfaces/.libs/libipopt.so* \
       $RPM_BUILD_ROOT%{_libmpidir}
%if 0%{?with_asl}
cp -a %{name}-%{version}-openmpi/src/Apps/AmplSolver/.libs/libipoptamplinterface.so* \
       $RPM_BUILD_ROOT%{_libmpidir}
install -pm 755 %{name}-%{version}-openmpi/src/Apps/AmplSolver/.libs/ipopt \
       $RPM_BUILD_ROOT%{_binmpidir}
%endif

cd %{name}-%{version}-openmpi
 for i in `find ./.* -type f \( -name "*.h" -o -name "*.hpp" \)`; do
 cp -p $i headers

# bz#1375290
 rm -f headers/strings.h
done
cd ..

##Copy MPI header files
install -p -m 644 %{name}-%{version}-openmpi/headers/* $RPM_BUILD_ROOT%{_incmpidir}

%endif

#######################################################
#######################################################
## Install MPICH version
%if 0%{?with_mpich}

mkdir -p $RPM_BUILD_ROOT%{_libmpichdir}
mkdir -p $RPM_BUILD_ROOT%{_binmpichdir}
mkdir -p $RPM_BUILD_ROOT%{_incmpichdir}
mkdir -p %{name}-%{version}-mpich/headers

cp -a %{name}-%{version}-mpich/src/Interfaces/.libs/libipopt.so* \
       $RPM_BUILD_ROOT%{_libmpichdir}
%if 0%{?with_asl}
cp -a %{name}-%{version}-mpich/src/Apps/AmplSolver/.libs/libipoptamplinterface.so* \
       $RPM_BUILD_ROOT%{_libmpichdir}
install -pm 755 %{name}-%{version}-mpich/src/Apps/AmplSolver/.libs/ipopt \
       $RPM_BUILD_ROOT%{_binmpichdir}
%endif

cd %{name}-%{version}-mpich
 for i in `find ./.* -type f \( -name "*.h" -o -name "*.hpp" \)`; do
 cp -p $i headers

# bz#1375290
 rm -f headers/strings.h
done
cd ..

##Copy MPI header files
install -p -m 644 %{name}-%{version}-mpich/headers/* $RPM_BUILD_ROOT%{_incmpichdir}

%endif

#######################################################

## Install serial version

mkdir -p $RPM_BUILD_ROOT%{_libdir}/pkgconfig
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_includedir}/coin
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}

mkdir -p %{name}-%{version}-serial/headers

##Copy libraries
cp -a %{name}-%{version}-serial/src/Interfaces/.libs/libipopt.so* \
       $RPM_BUILD_ROOT%{_libdir}
install -p -m 644 %{name}-%{version}-serial/ipopt.pc $RPM_BUILD_ROOT%{_libdir}/pkgconfig
%if 0%{?with_asl}
cp -a %{name}-%{version}-serial/src/Apps/AmplSolver/.libs/libipoptamplinterface.so* \
       $RPM_BUILD_ROOT%{_libdir}
install -pm 755 %{name}-%{version}-serial/src/Apps/AmplSolver/.libs/ipopt \
       $RPM_BUILD_ROOT%{_bindir}
%endif

cd %{name}-%{version}-serial
 for i in `find ./.* -type f \( -name "*.h" -o -name "*.hpp" \)`; do
 cp -p $i headers
done
cd ..

##Copy header and documentation files
install -p -m 644 %{name}-%{version}-serial/headers/* $RPM_BUILD_ROOT%{_includedir}/coin

# Correct config.h due to manual install (#1295290)
pushd $RPM_BUILD_ROOT%{_includedir}/coin/
    rm config.h config_default.h
    # Use the generated config_ipopt.h
    sed -i 's/\(config_ipopt\)_default\(\.h\)/\1\2/' IpoptConfig.h
popd

cp -far %{name}-%{version}-serial/doxydoc/html $RPM_BUILD_ROOT%{_docdir}/%{name}
cp -p doc/documentation.pdf $RPM_BUILD_ROOT%{_docdir}/%{name}/Ipopt_Tutorial.pdf

#######################################################

%check

cd %{name}-%{version}-serial
%if 0%{?with_asl}
%if 0%{?rhel} && 0%{?rhel} < 7
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libdir}:%{_libdir}:%{_libdir}/mp
%else
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libdir}:%{_libdir}
%endif
%endif
make test
cd ..

%if 0%{?with_openmpi}
%{_openmpi_load}
cd %{name}-%{version}-openmpi
%if 0%{?with_asl}
%if 0%{?rhel} && 0%{?rhel} < 7
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libmpidir}:%{_libmpidir}:%{_libdir}/mp
%else
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libmpidir}:%{_libmpidir}
%endif
%endif
make test
cd ..
%{_openmpi_unload}
%endif
%if 0%{?with_mpich}
%{_mpich_load}
cd %{name}-%{version}-mpich
%if 0%{?with_asl}
%if 0%{?rhel} && 0%{?rhel} < 7
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libmpichdir}:%{_libmpichdir}:%{_libdir}/mp
%else
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libmpichdir}:%{_libmpichdir}
%endif
%endif
MPICH_INTERFACE_HOSTNAME=localhost make test
cd ..
%{_mpich_unload}
%endif

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%if 0%{?with_asl}
%{_bindir}/ipopt
%endif
%{_libdir}/*.so.*

%files	devel
%{_includedir}/coin/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

#######################################################
## Install MPI version
%if 0%{?with_openmpi}

%files openmpi
%if 0%{?with_asl}
%{_binmpidir}/ipopt
%endif
%{_libmpidir}/*.so.*

%files openmpi-devel
%{_libmpidir}/*.so
%{_incmpidir}/*

%endif
%if 0%{?with_mpich}

%files mpich
%if 0%{?with_asl}
%{_binmpichdir}/ipopt
%endif
%{_libmpichdir}/*.so.*

%files mpich-devel
%{_libmpichdir}/*.so
%{_incmpichdir}/*

%endif

%files common
%doc AUTHORS LICENSE
%license LICENSE
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/html
%{_docdir}/%{name}/*.pdf

%changelog
* Sun Oct 29 2017 Antonio Trande <sagitterATfedoraproject.org> - 3.12.8-5
- Rebuild for MUMPS-5.1.2

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.12.8-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.12.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Thu Jun 29 2017 Antonio Trande <sagitterATfedoraproject.org> - 3.12.8-2
- Rebuild for MUMPS-5.1.1 (after a bug-fix)

* Wed Jun 14 2017 Antonio Trande <sagitterATfedoraproject.org> - 3.12.8-1
- Update to 3.12.8

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.12.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Thu Mar 23 2017 Antonio Trande <sagitterATfedoraproject.org> - 3.12.7-2
- Rebuild for MUMPS-5.1.1

* Sat Feb 25 2017 Antonio Trande <sagitterATfedoraproject.org> - 3.12.7-1
- Update to 3.12.7 (bz#1426828)
- Build on Fedora >= 26 s390x
- Update patch0

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.12.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Nov 01 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.12.6-4
- New architectures
- Build on s390

* Fri Oct 21 2016 Orion Poplawski <orion@cora.nwra.com> - 3.12.6-3
- Rebuild for openmpi 2.0

* Tue Sep 20 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.12.6-2
- Exclude strings.h wrapper installation (bz#1375290)

* Thu Jul 21 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.12.6-1
- Update to 3.12.6

* Tue Jul 19 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.12.5-4
- ASL enabled on EPEL
- Rebuild for MUMPS-5.0.2

* Sun May 15 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.12.5-3
- PPC64 excluded on EPEL6

* Sun May 15 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.12.5-2
- Install ipopt binary files (bz#1320049)

* Mon May 02 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.12.5-1
- Update to 3.12.5
- MPICH libraries built on PPC64*

* Thu Apr 07 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.12.4-12
- Fixed with_asl macro

* Wed Mar 16 2016 Paulo Andrade <paulo.cesar.pereira.de.andrade@gmail.com> - 3.12.4-11
- Correct side effect of previous change on armv7hl

* Wed Mar 16 2016 Paulo Andrade <paulo.cesar.pereira.de.andrade@gmail.com> - 3.12.4-10
- Correct HAVE_CONFIG_H dependency due to manual install (#1295290)

* Sat Mar 05 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.12.4-9
- Rebuild for mp 3.0.1

* Wed Feb 10 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.12.4-8
- PPC64 excluded on EPEL6

* Thu Feb 04 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.12.4-7
- Build MPICH libraries
- Built on EPEL

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.12.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Oct 30 2015 Antonio Trande <sagitterATfedoraproject.org> - 3.12.4-5
- Hardened builds on <F23
- Set metis lib
- Set global ldflags

* Wed Sep 16 2015 Orion Poplawski <orion@cora.nwra.com> - 3.12.4-4
- Rebuild for openmpi 1.10.0

* Sun Aug 16 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 3.12.4-3
- Rebuild for MPI provides

* Mon Aug 10 2015 Sandro Mani <manisandro@gmail.com> - 3.12.4-2
- Rebuild for RPM MPI Requires Provides Change

* Mon Aug 10 2015 Antonio Trande <sagitterATfedoraproject.org> - 3.12.4-1
- Update to 3.12.4

* Sat Jun 20 2015 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.12.2-3
- Full rebuild of coin-or stack.

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.12.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Apr 18 2015 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 3.12.3-1
- Update to 3.12.3 (#1213024)

* Sun Apr 05 2015 Antonio Trande <sagitterATfedoraproject.org> - 3.12.2-1
- Update to 3.12.2

* Mon Mar 09 2015 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.12.1-5
- Rebuild (MUMPS broken dependencies on F22)

* Sun Feb 22 2015 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.12.1-4
- Add conditional to enable the asl solver

* Sun Feb 22 2015 Antonio Trande <sagitterATfedoraproject.org> - 3.12.1-3
- Rebuild again (broken dependencies)

* Sat Feb 21 2015 Antonio Trande <sagitterATfedoraproject.org> - 3.12.1-2
- Rebuild after MUMPS update

* Tue Feb 17 2015 Antonio Trande <sagitterATfedoraproject.org> - 3.12.1-1
- Update to 3.12.1

* Wed Feb 04 2015 Marcin Juszkiewicz <mjuszkiewicz@redhat.com> - 3.12.0-2
- Correct aarch64 build again (#1185848)

* Tue Jan 27 2015 Antonio Trande <sagitterATfedoraproject.org> - 3.12.0-1
- Update to 3.12.0 (bz#1152812)

* Mon Jan 26 2015 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.11.10-3
- Correct aarch64 build (#1185848)

* Fri Jan 23 2015 Antonio Trande <sagitterATfedoraproject.org> - 3.11.10-2
- Fix libraries's symlinks (bz#1152812)

* Mon Jan 19 2015 Antonio Trande <sagitterATfedoraproject.org> - 3.11.10-1
- Update to 3.11.10

* Sun Oct 26 2014 Peter Robinson <pbrobinson@fedoraproject.org> - 3.11.9-4
- Update config.guess config.sub for new arch (aarch64/ppc64le) support

* Sat Oct 04 2014 Antonio Trande <sagitterATfedoraproject.org> - 3.11.9-3
- Obsolete coin-or-Ipopt-doc sub-package

* Tue Sep 09 2014 Antonio Trande <sagitterATfedoraproject.org> - 3.11.9-2
- Performed conditional openmpi build macro
- Built libraries against OpenMPI
- Built -openmpi sub-packages
- Built a common sub-package
- Performed serial and parallel tests

* Sat Aug 30 2014 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.11.9-1
- Update to latest upstream release (#1131008)

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.11.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Jul 9 2014 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.11.8-1
- Add missing requires to MUMPS-devel in the devel package
- Do not explicitly link to openmpi
- Update to version that corrects #1117974
- Update to latest upstream release (#1089927)

* Fri Jun 13 2014 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.11.0-6
- Adapt to newer scalapack correcting rawhide FTBFS (#1106072)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.11.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Apr  7 2014 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.11.0-4
- Correct files conflict (#1084893).

* Wed Aug  7 2013 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.11.0-3
- Switch to unversioned docdir.
- Correct rawhide FTBFS (#992075).

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.11.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat May 11 2013 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.11.0-1
- Update to latest upstream release.
- Adjust patches and build for sources now in toplevel directory.

* Thu May 9 2013 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.10.4-1
- Update to latest upstream release.
- Switch to the new upstream tarballs without bundled dependencies.

* Sat Mar  2 2013 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.10.3-2
- Remove ThirdParty directory.
- Make use of the MUMPS solver (#913152).
- Split html documentation in a doc package.

* Mon Jan 14 2013 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.10.3-1
- Update to latest upstream release.

* Sat Jan 12 2013 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.10.2-3
- Rename repackaged tarball.

* Sun Nov 18 2012 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.10.2-2
- Rename package to coin-or-Ipopt.
- Do not package Thirdy party data or data without clean license.

* Sat Sep 29 2012 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 3.10.2-1
- Initial coinor-Ipopt spec.

